@@ -47,7 +47,7 @@ public:
     /**
       Destructor
     */
-    virtual ~Transport();
+    ~Transport() override;
 
     typedef QList<Transport *> List;
 
@@ -124,6 +124,8 @@ public:
     */
     TransportType transportType() const;
 
+    QByteArray toJson() const;
+
 protected:
     /**
       Creates a Transport object. Should only be used by TransportManager.
