@@ -27,6 +27,7 @@
 #include "plugins/transportpluginmanager.h"
 #include "plugins/transportabstractplugin.h"
 #include "widgets/addtransportdialogng.h"
+#include <MailTransport/TransportAbstractPlugin>
 
 #include <QApplication>
 #include <QDBusConnection>
@@ -45,7 +46,7 @@
 #include <KRandom>
 #include <Kdelibs4ConfigMigrator>
 
-#include <KWallet/kwallet.h>
+#include <KWallet>
 
 using namespace MailTransport;
 using namespace KWallet;
@@ -71,18 +72,18 @@ public:
         qDeleteAll(transports);
     }
 
-    KConfig *config;
+    KConfig *config = nullptr;
     QList<Transport *> transports;
     TransportType::List types;
     bool myOwnChange;
     bool appliedChange;
-    KWallet::Wallet *wallet;
+    KWallet::Wallet *wallet = nullptr;
     bool walletOpenFailed;
     bool walletAsyncOpen;
     int defaultTransportId;
     bool isMainInstance;
     QList<TransportJob *> walletQueue;
-    TransportManager *q;
+    TransportManager *q = nullptr;
 
     void readConfig();
     void writeConfig();
@@ -140,8 +141,9 @@ TransportManager::TransportManager()
     QDBusServiceWatcher *watcher
         = new QDBusServiceWatcher(DBUS_SERVICE_NAME, QDBusConnection::sessionBus(),
                                   QDBusServiceWatcher::WatchForUnregistration, this);
-    connect(watcher, SIGNAL(serviceUnregistered(QString)),
-            SLOT(dbusServiceUnregistered()));
+    connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
+        d->dbusServiceUnregistered();
+    });
 
     QDBusConnection::sessionBus().connect(QString(), QString(),
                                           DBUS_INTERFACE_NAME, DBUS_CHANGE_SIGNAL,
@@ -169,7 +171,7 @@ TransportManager *TransportManager::self()
 
 Transport *TransportManager::transportById(int id, bool def) const
 {
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         if (t->id() == id) {
             return t;
         }
@@ -183,7 +185,7 @@ Transport *TransportManager::transportById(int id, bool def) const
 
 Transport *TransportManager::transportByName(const QString &name, bool def) const
 {
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         if (t->name() == name) {
             return t;
         }
@@ -227,7 +229,9 @@ void TransportManager::addTransport(Transport *transport)
 
 void TransportManager::schedule(TransportJob *job)
 {
-    connect(job, SIGNAL(result(KJob *)), SLOT(jobResult(KJob *)));
+    connect(job, &TransportJob::result, this, [this](KJob *job) {
+        d->jobResult(job);
+    });
 
     // check if the job is waiting for the wallet
     if (!job->transport()->isComplete()) {
@@ -281,7 +285,7 @@ void TransportManager::initializeTransport(const QString &identifier, Transport
 {
     TransportAbstractPlugin *plugin = TransportPluginManager::self()->plugin(identifier);
     if (plugin) {
-        return plugin->initializeTransport(transport, identifier);
+        plugin->initializeTransport(transport, identifier);
     }
 }
 
@@ -340,7 +344,7 @@ QVector<int> TransportManager::transportIds() const
 {
     QVector<int> rv;
     rv.reserve(d->transports.count());
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         rv << t->id();
     }
     return rv;
@@ -350,7 +354,7 @@ QStringList TransportManager::transportNames() const
 {
     QStringList rv;
     rv.reserve(d->transports.count());
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         rv << t->name();
     }
     return rv;
@@ -496,7 +500,6 @@ void TransportManagerPrivate::updatePluginList()
     }
 }
 
-
 void TransportManager::updatePluginList()
 {
     d->updatePluginList();
@@ -724,5 +727,3 @@ void TransportManagerPrivate::jobResult(KJob *job)
 }
 
 #include "moc_transportmanager.cpp"
-
-#include <MailTransport/TransportAbstractPlugin>
