@@ -22,7 +22,7 @@
 
 #include <mailtransportakonadi_export.h>
 
-#include <QtCore/QString>
+#include <QString>
 
 #include <attribute.h>
 
@@ -48,7 +48,7 @@ public:
     /**
      * Destroys the error attribute.
      */
-    virtual ~ErrorAttribute();
+    ~ErrorAttribute() override;
 
     /**
      * Returns the i18n'ed error message.
@@ -61,10 +61,10 @@ public:
     void setMessage(const QString &msg);
 
     /* reimpl */
-    ErrorAttribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    ErrorAttribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
 private:
     //@cond PRIVATE
